==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigProxyFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigProxyFluentImpl<A extends ImageRegistryConfigProxyFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigProxyFluent<A>{
  public ImageRegistryConfigProxyFluentImpl() {
  }
  public ImageRegistryConfigProxyFluentImpl(ImageRegistryConfigProxy instance) {
    this.withHttp(instance.getHttp()); 
    this.withHttps(instance.getHttps()); 
    this.withNoProxy(instance.getNoProxy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String http;
  private String https;
  private String noProxy;
  private Map<String,Object> additionalProperties;
  public String getHttp() {
    return this.http;
  }
  public A withHttp(String http) {
    this.http=http; return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public String getHttps() {
    return this.https;
  }
  public A withHttps(String https) {
    this.https=https; return (A) this;
  }
  public Boolean hasHttps() {
    return this.https != null;
  }
  public String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigProxyFluentImpl that = (ImageRegistryConfigProxyFluentImpl) o;
    if (http != null ? !http.equals(that.http) :that.http != null) return false;
    if (https != null ? !https.equals(that.https) :that.https != null) return false;
    if (noProxy != null ? !noProxy.equals(that.noProxy) :that.noProxy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(http,  https,  noProxy,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (https != null) { sb.append("https:"); sb.append(https + ","); }
    if (noProxy != null) { sb.append("noProxy:"); sb.append(noProxy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigProxyFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigProxyFluentImpl<A extends ImageRegistryConfigProxyFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigProxyFluent<A>{
  public ImageRegistryConfigProxyFluentImpl() {
  }
  public ImageRegistryConfigProxyFluentImpl(ImageRegistryConfigProxy instance) {
    if (instance != null) {
      this.withHttp(instance.getHttp());
      this.withHttps(instance.getHttps());
      this.withNoProxy(instance.getNoProxy());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String http;
  private String https;
  private String noProxy;
  private Map<String,Object> additionalProperties;
  public String getHttp() {
    return this.http;
  }
  public A withHttp(String http) {
    this.http=http; return (A) this;
  }
  public Boolean hasHttp() {
    return this.http != null;
  }
  public String getHttps() {
    return this.https;
  }
  public A withHttps(String https) {
    this.https=https; return (A) this;
  }
  public Boolean hasHttps() {
    return this.https != null;
  }
  public String getNoProxy() {
    return this.noProxy;
  }
  public A withNoProxy(String noProxy) {
    this.noProxy=noProxy; return (A) this;
  }
  public Boolean hasNoProxy() {
    return this.noProxy != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigProxyFluentImpl that = (ImageRegistryConfigProxyFluentImpl) o;
    if (!java.util.Objects.equals(http, that.http)) return false;

    if (!java.util.Objects.equals(https, that.https)) return false;

    if (!java.util.Objects.equals(noProxy, that.noProxy)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(http,  https,  noProxy,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (http != null) { sb.append("http:"); sb.append(http + ","); }
    if (https != null) { sb.append("https:"); sb.append(https + ","); }
    if (noProxy != null) { sb.append("noProxy:"); sb.append(noProxy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
